#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.3.0.0-GITCCcpqLkVIvc1KnKn1Uh

key:
    hls-explicit-record-fields-plugin-2.3.0.0-GITCCcpqLkVIvc1KnKn1Uh

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bdbecd15c263134312d948aa22fd476f
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.3.0.0-GITCCcpqLkVIvc1KnKn1Uh

depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1 containers-0.6.7
    ghc-9.6.6 ghc-boot-th-9.6.6 ghcide-2.3.0.0-CcK2wSaq05YKYa0NGFtpAc
    hls-graph-2.3.0.0-1z80l9DPzvC9twCkDucgLx
    hls-plugin-api-2.3.0.0-9jNGutJrgQb5AA08encVmk
    lens-5.3.4-9D2yk6aQnpf3ebTPLPYG20
    lsp-2.2.0.0-Ht4b9oRKJPDKygwdJbTllZ syb-0.7.3-GhxEKVO9aRZHddME5iK0hL
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

